<template>
    <div class="screen-header">
        <div class="header-left-wrapper">
            <el-select
                class="header-toll-search"
                v-model="tollStationId"
                filterable
                placeholder="收费站"
                @change="changeTollStation"
                :popper-append-to-body="false"
            >
                <el-option
                    v-for="item in tollStationOptions"
                    :key="item.id"
                    :label="item.name"
                    :value="item.id"
                >
                </el-option>
            </el-select>
            <el-date-picker
                class="header-date-search-input"
                popper-class="header-date-search"
                v-model="searchTime"
                type="month"
                placeholder="选择月"
                :editable="false"
                :clearable="false"
                @change="changeMonth"
                v-show="menuActived == 'operationFees'"
            >
            </el-date-picker>
        </div>
        <div class="header-center-wrapper flex-between">
            <div class="btn-group btn-group-left flex-end">
                <div
                    v-for="item in menuData.slice(0, 2)"
                    :key="item.alias"
                    :class="['menu-item', {active: menuActived == item.alias}]"
                    @click="enterMenu(item.alias)"
                >
                    <span>{{ item.name }}</span>
                </div>
            </div>
            <div class="sys-info flex-center">
                <img class="logo" :src="logoUrl" />
                <div class="title">
                    {{ sysName }}
                </div>
            </div>
            <div class="btn-group btn-group-right flex-start">
                <div
                    v-for="item in menuData.slice(2, 4)"
                    :key="item.alias"
                    :class="['menu-item', {active: menuActived == item.alias}]"
                    @click="enterMenu(item.alias)"
                >
                    <span>{{ item.name }}</span>
                </div>
            </div>
        </div>
        <div class="header-right-wrapper">
            <!-- <div class="tool-weather" :title="weathernow">
                <img class="weather-icon" :src="weatherIcon" alt="image" />
                {{ weathernow }}
            </div>
            <span class="line"></span> -->
            <div class="tool-day">{{ daynow }}</div>
            <span class="line"></span>
            <div class="tool-time">{{ timenow }}</div>
            <div class="sys" @click="handleSys" title="服务系统">
                <img src="../../assets/img/bigScreen/icon-sys.png" />
            </div>
            <div class="logout" @click="handleLogout" title="退出">
                <img src="../../assets/img/bigScreen/icon-logout.png" />
            </div>
        </div>
        <div
            class="sysmenu-container-mask"
            v-if="showWorkSysMask"
            @click="handleSys"
        >
            <div
                :class="[
                    'sysmenu-container',
                    'flex-center',
                    {show: showWorkSys},
                ]"
            >
                <div
                    @click="changeNormal(workItem)"
                    :class="['menu-item']"
                    v-for="(workItem, index) in workPlatMenu[0].children"
                    :key="index"
                >
                    {{ workItem.name }}
                </div>
            </div>
        </div>
    </div>
</template>



<script>
import commomAPI from '@/api/bigScreen/common.js'
import routerManagement from '@/api/BasicDataManagement/tollStationManagement.js'
import utils from '@/utils'
import moment from 'moment'
export default {
    name: 'bigScreen',
    data() {
        return {
            searchTime: moment().format('YYYY-MM'),
            sysName: '',
            logoUrl: '',
            menuData: [],
            workPlatMenu: [],
            showWorkPlat: false,
            timenow: '',
            daynow: '',
            weathernow: '',
            activeIndex: '1',
            weatherIcon: '',
            hournow: '',
            workPlatData: [],
            menuActived: '',
            timer: null,
            showWorkSys: false,
            showWorkSysMask: false,
            tollStationId: '',
            tollStationOptions: [], // 收费站数据
        }
    },
    mounted() {
        this.menuActived = this.$route.name
        this.getSysInfo()
        this.getTimeNow()
        // this.getWeather()
        this.getMenu()
    },
    activated() {
        this.loadTollStation()
        this.menuActived = this.$route.name
        this.tollStationId = sessionStorage.getItem('tollStationId')
    },
    methods: {
        showtip() {
            this.$parent.showTip()
        },
        // 收费站
        loadTollStation() {
            let params = {
                pageBean: {
                    page: 1,
                    pageSize: -1,
                },
            }
            this.tollStationId = sessionStorage.getItem('tollStationId')
            routerManagement.queryTollStation(params).then((res) => {
                let data = res.data
                this.tollStationOptions = data.rows || []
                if (!this.tollStationId) {
                    this.tollStationId = this.tollStationOptions[0].id
                    sessionStorage.setItem('tollStationId', this.tollStationId)
                    this.$emit('changeTollStation')
                }
            })
        },
        // 收费站信息
        changeTollStation(val) {
            sessionStorage.setItem('tollStationId', val)
            this.$emit('changeTollStation')
        },
        // 获取年月
        changeMonth(val) {
            this.$emit('changeMonth', val.format('yyyy-MM'))
            this.showtip()
        },
        // 获取系统信息
        getSysInfo() {
            let sysinfo = sessionStorage.getItem('sysinfo')
            if (sysinfo) {
                sysinfo = JSON.parse(sysinfo)
                this.logoUrl = sysinfo.logoUrl
                this.sysName = sysinfo.sysName
            } else {
                let url =
                    '${uc}/uc/tenantManage/v1/getTenantByCode?code=platform'
                this.$http.get(url).then((resp) => {
                    if (resp.data) {
                        let tenantManage = resp.data
                        this.sysName = tenantManage.nameFront
                        if (tenantManage.frontLogo) {
                            let frontLogo = JSON.parse(tenantManage.frontLogo)
                            if (frontLogo && frontLogo.length > 0) {
                                this.logoUrl =
                                    window.context.portal +
                                    '/file/onlinePreviewController/v1/getFileById_' +
                                    frontLogo[0].id

                                let sysinfo = {
                                    logoUrl: this.logoUrl,
                                    sysName: this.sysName,
                                }
                                sessionStorage.setItem(
                                    'sysinfo',
                                    JSON.stringify(sysinfo)
                                )
                            }
                        }
                    }
                })
            }
        },
        getWeather() {
            let ss = sessionStorage.getItem('weathernow')
            if (ss) {
                this.getWeatherIcon(JSON.parse(ss))
            } else {
                commomAPI
                    .queryWeather()
                    .then((res) => {
                        console.log('res', res)
                        // console.log('获取的数据' + res.data.lives[0].weather)
                        this.weathernow = res.data.lives[0].weather
                        this.getWeatherIcon(this.weathernow)
                        sessionStorage.setItem(
                            'weathernow',
                            JSON.stringify(this.weathernow)
                        )
                    })
                    .catch((err) => {
                        console.log('err', err)
                    })
            }
        },
        getMenu() {
            this.$store.dispatch('menu/actionFrontMenus').then((data) => {
                let bigScreen =
                    data && data.filter((item) => item.alias === 'bigScreen')
                if (bigScreen[0].children.length !== 0) {
                    bigScreen[0].children.forEach((item) => {
                        if (item.alias != 'workPlat') {
                            this.menuData.push(item)
                        } else {
                            this.workPlatMenu.push(item)
                        }
                    })
                    if (this.workPlatMenu.length) this.showWorkPlat = true
                }
            })
        },
        // 切换不同大屏菜单
        enterMenu(alias) {
            if (alias == 'workPlat') {
                return
            } else {
                this.$router.push({
                    path: '/' + alias,
                })
            }
        },
        // 切换工作台
        changeNormal(item) {
            console.log('我切换了', item)
            if (item.alias == 'normal') {
                if (
                    item.children[0].length !== 0 &&
                    item.children[0].children.length
                ) {
                    this.$router.push({
                        path: `/platLayout/${item.children[0].children[0].alias}`,
                    })
                } else {
                    this.$router.push({
                        path: `/platLayout/${item.children[0].alias}`,
                    })
                }
            } else if (item.alias.indexOf('href') !== -1) {
                window.open(item.href, '_blank')
            }
        },
        // 其他系统
        handleSys() {
            // setTimeout(() => {
            //     this.showWorkSysMask = !this.showWorkSysMask
            // }, 500)
            if (this.showWorkSysMask) {
                this.showWorkSys = !this.showWorkSys
                setTimeout(() => {
                    this.showWorkSysMask = false
                }, 400)
            } else {
                this.showWorkSysMask = !this.showWorkSysMask
                setTimeout(() => {
                    this.showWorkSys = !this.showWorkSys
                }, 100)
            }
        },
        // 退出登陆
        handleLogout() {
            this.$store.dispatch('menu/clearMenus')
            this.$store.dispatch('user/clearUser')
            this.$store.dispatch('menu/setCopyMenus', []) //菜单
            let loginRouthPath =
                localStorage.getItem(
                    this.$store.state.login.currentUser.account +
                        'loginRoutePath'
                ) || '/login'
            this.$store.dispatch('login/logoutAndCleanUp').then(() => {
                switch (window.ssoConfig.mode) {
                    case 'cas':
                    case 'oauth':
                        window.sessionStorage.removeItem('currentUser')
                        window.location.href =
                            window.ssoConfig.logout +
                            '?service=' +
                            window.location.href.split('?')[0]
                        break
                    default:
                        this.$router.push({
                            path: loginRouthPath,
                        })
                        break
                }
            })
        },
        // 实时获取
        getTimeNow() {
            this.daynow = moment().format('YYYY年MM月DD日')
            this.timenow = moment().format('HH:mm:ss')
            this.timer = setInterval(() => {
                this.timenow = moment().format('HH:mm:ss')
            }, 1000)
        },
        clear() {
            clearInterval(this.timer)
        },
        // 工作台二级菜单
        handleSelect(key, keyPath) {
            console.log(key, keyPath)
        },
        // 获取天气icon
        getWeatherIcon(weather) {
            this.hournow = moment().format('hh') // 获取时间 判断半天黑夜
            this.weathernow = weather
            if (
                this.hournow > 6 &&
                this.hournow < 19 &&
                this.weathernow == '晴'
            ) {
                this.weatherIcon = require('@/assets/img/weather/qing.png')
            } else if (
                this.hournow > 6 &&
                this.hournow < 19 &&
                this.weathernow == '多云的'
            ) {
                this.weatherIcon = require('@/assets/img/weather/duoyun.png')
            } else if (this.weathernow == '阴') {
                this.weatherIcon = require('@/assets/img/weather/yin.png')
            } else if (this.weathernow == '霾') {
                this.weatherIcon = require('@/assets/img/weather/yin.png')
            } else if (this.weathernow == '雷阵雨') {
                this.weatherIcon = require('@/assets/img/weather/leizhenyu.png')
            } else if (this.weathernow == '雨') {
                this.weatherIcon = require('@/assets/img/weather/xiaoyu.png')
            } else if (this.weathernow == '小雨') {
                this.weatherIcon = require('@/assets/img/weather/xiaoyu.png')
            } else if (this.weathernow == '中雨') {
                this.weatherIcon = require('@/assets/img/weather/zhongyu.png')
            } else if (this.weathernow == '大雨') {
                this.weatherIcon = require('@/assets/img/weather/dayu.png')
            } else if (this.weathernow == '暴雨') {
                this.weatherIcon = require('@/assets/img/weather/baoyu.png')
            } else if (this.weathernow == '大暴雨') {
                this.weatherIcon = require('@/assets/img/weather/baoyu.png')
            } else if (
                this.weathernow == '中雨-大雨' ||
                this.weathernow == '小雨-中雨' ||
                this.weathernow == '大雨-暴雨' ||
                this.weathernow == '暴雨-大暴雨'
            ) {
                this.weatherIcon = require('@/assets/img/weather/dayu.png')
            } else if (this.weathernow.indexOf('风') != -1) {
                this.weatherIcon = require('@/assets/img/weather/dafeng.png')
            } else if (
                this.hournow < 6 &&
                this.hournow > 19 &&
                this.weathernow == '多云都'
            ) {
                this.weatherIcon = require('@/assets/img/weather/duoyunye.png')
            } else if (
                this.hournow < 6 &&
                this.hournow > 19 &&
                this.weathernow == '晴'
            ) {
                this.weatherIcon = require('@/assets/img/weather/qingye.png')
            } else {
                this.weatherIcon = require('@/assets/img/weather/yin.png')
            }
        },
        beforeDestroy() {
            this.clear()
        },
    },
}
</script>

<style lang="scss" scoped>

.screen-header{
    position: absolute;
    left: 0;
    top: 0;
    width: 100%;
    height: 80px;
    line-height: 80px;
    display: flex;
    background: url('../../assets/img/bigScreen/nav-bg.png') no-repeat center / 100%;
    z-index: 999;
}
.header-center-wrapper{
    width: 1160px;
    .btn-group{
        width: 330px;
        .menu-item{
            width: 172px;
            height: 55px;
            display: flex;
            justify-content: center;
            align-items: center;
            cursor: pointer;
            span{
                font-size: 16px;
                font-weight: 400;
                color: #fff;
                margin-top: 4px;
            }
        }
    }
    .btn-group-left{
        .menu-item:nth-of-type(1){
            margin-right: -25px;
        }
        .menu-item{
            background: url('../../assets/img/bigScreen/nav-btn-left.png') no-repeat center / 100%;
            span{
                margin-left: 10px;
            }
        }
        .menu-item:hover,.menu-item.active{
            background: url('../../assets/img/bigScreen/nav-btn-left-active.png') no-repeat center / 100%;
            span{
                font-weight: bold;
            }
        }
    }
    .btn-group-right{
        .menu-item:nth-of-type(2){
            margin-left: -25px;
        }
        .menu-item{
            background: url('../../assets/img/bigScreen/nav-btn-right.png') no-repeat center / 100%;
            span{
                margin-right: 10px;
            }
        }
        .menu-item:hover,.menu-item.active{
            background: url('../../assets/img/bigScreen/nav-btn-right-active.png') no-repeat center / 100%;
            span{
                font-weight: bold;
            }
        }
    }
    .sys-info{
        gap: 8px;
        .logo{
            width: 50px;
            height: 50px;
        }
        .title{
            font-size: 34px;
            color: #fff;
            font-weight: bold;
            font-family: PingFang SC;
        }
    }
}
.header-left-wrapper,.header-right-wrapper{
    width: 380px;
    display: flex;
    box-sizing: border-box;
}
.header-left-wrapper{
    padding-left: 16px;
    justify-content: flex-start;
    align-items: center;
    gap: 10px;
    /deep/.el-input__inner {
        background-color: transparent;
        color: #FFFFFF;
        border:1px solid #2C4E91;
        text-align: center;
        font-size: 16px;
        font-weight: 700;
    }
    
    /deep/.el-input__prefix{
        left: 10px;
        
    }
    /deep/.el-input__icon{
        font-size: 16px;
        color: #fff;
    }

}
.header-right-wrapper{
    justify-content: flex-end;
    align-items: center;
    padding-right: 16px;
}


.tool-weather{
    height: 23px; 
    font-size: 14px;
    font-weight: 400;
    line-height: 23px;
    text-align: center;
    color: #FFFFFF;
    display: flex;
    align-items: center;
    overflow: hidden;
    white-space: nowrap;
    text-overflow: ellipsis;
}
.tool-day{
    height: 30px;
    font-size: 12px;
    font-weight: 400;
    color: #FFFFFF;
    line-height: 30px;
}

.line{
    display: inline-block;
    box-sizing: border-box;
    width: 1px;
    height: 10px;
    background: #B2B2B2;
    margin:0 8px;
}
.tool-time{ 
    height: 30px;
    font-size: 18px;
    font-weight: 700;
    color: #FFFFFF;
    line-height: 30px;
    font-family: PingFang SC;
}
.sys, .logout{
    width: 32px;
    height: 38px;
    margin-left: 16px;
    display: flex;
    align-items: center;
    justify-content: center;
    cursor: pointer;
    img{
        width: 100%;
        height: 100%;
    }
}

.company-name{
  width: 150px;
  height: 100%;
  margin-left: 16px;
}
.company-name img{
    width: 146px;
    height: 34px;
    margin-top: 13px;
}
.system-name{
  width: 180px;
  height: 100%;
  margin-left: 20px;
}
.system-name img{
    width: 180px;
    height: 100%;

}
.desk-menu{
    width: 900px;
    height: 100%;
    margin-left: 112px;
    display: flex;
    font-size: 18px;
    font-weight: 400;
}
.desk-menu-list{
    width: 150px;
    height: 100%;
    text-align: center;
    line-height: 60px;
    font-size: 18px;
    color: #fff;
    cursor: pointer;
    margin-top: 2px;
    background: url('../../assets/img/bigScreen/bg-list.png') no-repeat center / 158px 63px;
}
.desk-normal{
    width: 150px;
    height: 100%;
    text-align: center;
    line-height: 60px;
    font-size: 18px;
    color: #fff;
    cursor: pointer;
    margin-top: 2px;
    background: url('../../assets/img/bigScreen/bg-list.png') no-repeat center / 158px 63px;
}
.choose{
    /* background-color:#fbfbfb ; */
    color: #fff;
    font-weight: 700;
    margin-top: 2px;
    background: url('../../assets/img/bigScreen/bg-list-actived.png') no-repeat center / 158px 63px;
}

.weather-icon{
  width: 20px;
  height: 20px;
  margin-right: 5px;
}

.sysmenu-container-mask{
    position: absolute;
    left: 0;
    top: 0;
    width: 100vw;
    height: 100vh;
}
.sysmenu-container{
    position: absolute;
    width: 80%;
    height: 0;
    opacity: 0;
    top: 80px;
    left: 10%;
    backdrop-filter: blur(5px);
    background: linear-gradient(360deg, rgba(7,17,29,0.8) 0%, rgba(7,17,29,0.4) 100%);
    box-shadow: 0px 5px 20px 0px #4DA6FF;
    border-radius: 0px 0px 16px 16px;
    border: 2px solid;
    overflow: hidden;
    border-image: linear-gradient(90deg, rgba(204, 229, 255, 0), rgba(204, 229, 255, 1), rgba(255, 255, 255, 0)) 2 2;
    transition: all 0.1s linear;
}
.sysmenu-container.show{
    height: 120px;
    opacity: 1;
}
.sysmenu-container{
    .menu-item{
        width: 224px;
        height: 58px;
        line-height: 58px;
        text-align: center;
        color: #E5F2FF;
        font-size: 18px;
        border:2px solid transparent;
        cursor: pointer;
    }
    .menu-item.active,.menu-item:hover{
        background: rgba(38,83,128,0.47);
        box-shadow: inset 0px 0px 10px 0px #3399FF;
        border-radius: 8px 8px 8px 8px;
        border:2px solid #3399ff;
        font-weight: 700;
        color: #FFFFFF;
    }
}
.header-toll-search{
    /deep/ .el-select-dropdown,.el-popper{
        background-color:rgba(27, 27, 27, 0.4);
        backdrop-filter: blur(10px);
        border: 1px solid #2C4E91;
    }
    .el-select-dropdown__item{
        color: #fff;
    }
    .el-select-dropdown__item.hover, .el-select-dropdown__item:hover {
        background-color: rgba(51, 153, 255, 0.3);
        color: #53a9ff;
    }
    /deep/.el-popper[x-placement^="bottom"] .popper__arrow {
        border-bottom-color: #7d95cf;
    }
    /deep/.el-popper[x-placement^="bottom"] .popper__arrow::after {
        border-bottom-color: #2C4E91;
    }
}
.header-date-search-input.el-date-editor.el-input{
    width: 180px!important;
}
</style>
<style lang='scss'>
.header-date-search{
    &.el-picker-panel{
        background: rgba(27, 27, 27, 0.4)!important;
        backdrop-filter: blur(10px);
        border: 1px solid #2C4E91;
    }
    &.el-popper[x-placement^="bottom"] .popper__arrow {
        border-bottom-color: #7d95cf;
    }
    &.el-popper[x-placement^="bottom"] .popper__arrow::after {
        border-bottom-color: #2C4E91;
    }
    .el-date-picker__header--bordered {
        border-bottom: solid 1px #2C4E91;
    }
    .el-date-picker__header-label,.el-month-table td .cell,.el-picker-panel__icon-btn,.el-year-table td .cell{
        color: #fff;
    }
    .el-date-picker__header-label:hover,.el-month-table td .cell:hover,.el-picker-panel__icon-btn:hover,.el-year-table td .cell:hover{
        color: #3399ff;
    }
    
}
</style>